@@ -33,13 +33,13 @@
     </message>
     <message>
         <location filename="../lyricsfactory.cpp" line="53"/>
-        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
         <location filename="../lyricsfactory.cpp" line="52"/>
-        <source>This plugin retrieves lyrics from lyricsplugin.com</source>
-        <translation>Dieses Modul empfängt Liedtexte von lyricsplugin.com</translation>
+        <source>This plugin retrieves lyrics from LyricWiki</source>
+        <translation>Dieses Modul empfängt Liedtexte von LyricWiki</translation>
     </message>
 </context>
 <context>
@@ -51,11 +51,16 @@
     </message>
     <message>
         <location filename="../lyricswindow.cpp" line="67"/>
+        <location filename="../lyricswindow.cpp" line="91"/>
+        <location filename="../lyricswindow.cpp" line="97"/>
+        <location filename="../lyricswindow.cpp" line="105"/>
+        <location filename="../lyricswindow.cpp" line="113"/>
+        <location filename="../lyricswindow.cpp" line="124"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.cpp" line="127"/>
+        <location filename="../lyricswindow.cpp" line="165"/>
         <source>Lyrics: %1 - %2</source>
         <translation>Liedtext: %1 – %2</translation>
     </message>
@@ -65,13 +70,14 @@
         <translation>Keine Verbindung</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.cpp" line="115"/>
+        <location filename="../lyricswindow.cpp" line="118"/>
+        <location filename="../lyricswindow.cpp" line="153"/>
         <source>Not found</source>
         <translation>Es kann kein Liedtext für dieses Stück gefunden werden.</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.cpp" line="96"/>
-        <location filename="../lyricswindow.cpp" line="126"/>
+        <location filename="../lyricswindow.cpp" line="139"/>
+        <location filename="../lyricswindow.cpp" line="164"/>
         <source>Receiving</source>
         <translation>Daten werden empfangen</translation>
     </message>
