@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2011 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,24 +21,9 @@
 #include <QtGui>
 #include <QSettings>
 
-extern "C"
-{
-#if defined HAVE_FFMPEG_AVFORMAT_H
-#include <ffmpeg/avformat.h>
-#elif defined HAVE_LIBAVFORMAT_AVFORMAT_H
+extern "C"{
 #include <libavformat/avformat.h>
-#else
-#include <avformat.h>
-#endif
-
-
-#if defined HAVE_FFMPEG_AVCODEC_H
-#include <ffmpeg/avcodec.h>
-#elif defined HAVE_LIBAVCODEC_AVCODEC_H
 #include <libavcodec/avcodec.h>
-#else
-#include <avcodec.h>
-#endif
 }
 
 #include "ffmpegmetadatamodel.h"
@@ -51,14 +36,7 @@ extern "C"
 
 bool DecoderFFmpegFactory::supports(const QString &source) const
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    QStringList filters;
-    filters << "*.wma" << "*.ape";
-#if (LIBAVCODEC_VERSION_INT >= ((52<<16)+(20<<8)+0))
-    filters << "*.shn";
-#endif
-    filters = settings.value("FFMPEG/filters", filters).toStringList();
-    foreach(QString filter, filters)
+    foreach(QString filter, properties().filters)
     {
         QRegExp regexp(filter, Qt::CaseInsensitive, QRegExp::Wildcard);
         if (regexp.exactMatch(source))
@@ -70,17 +48,7 @@ bool DecoderFFmpegFactory::supports(const QString &source) const
 bool DecoderFFmpegFactory::canDecode(QIODevice *i) const
 {
     av_register_all();
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    QStringList filters;
-#if (LIBAVCODEC_VERSION_INT >= ((51<<16)+(44<<8)+0))
-    filters << "*.wma" << "*.ape";
-#else
-    filters << "*.wma";
-#endif
-#if (LIBAVCODEC_VERSION_INT >= ((52<<16)+(20<<8)+0))
-    filters << "*.shn";
-#endif
-    filters = settings.value("FFMPEG/filters", filters).toStringList();
+    QStringList filters = properties().filters;
 
     AVProbeData  pd;
     uint8_t buf[8192 + AVPROBE_PADDING_SIZE];
@@ -101,6 +69,8 @@ bool DecoderFFmpegFactory::canDecode(QIODevice *i) const
         return true;
     if(filters.contains("*.aac") && !memcmp(fmt->name, "aac", 3))
         return true;
+    if(filters.contains("*.ac3") && !memcmp(fmt->name, "ac3", 3))
+        return true;
     return false;
 }
 
@@ -108,30 +78,28 @@ const DecoderProperties DecoderFFmpegFactory::properties() const
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     QStringList filters;
-#if (LIBAVCODEC_VERSION_INT >= ((51<<16)+(44<<8)+0))
     filters << "*.wma" << "*.ape";
-#else
-    filters << "*.wma";
-#endif
-#if (LIBAVCODEC_VERSION_INT >= ((52<<16)+(20<<8)+0))
-    filters << "*.shn";
-#endif
     filters = settings.value("FFMPEG/filters", filters).toStringList();
     DecoderProperties properties;
     properties.name = tr("FFmpeg Plugin");
-    properties.filter = filters.join(" ");
+    properties.filters = filters;
     properties.description = tr("FFmpeg Formats");
     if(filters.contains("*.wma"))
-        properties.contentType += "audio/x-ms-wma";
+        properties.contentTypes << "audio/x-ms-wma";
     if(filters.contains("*.mp3"))
-        properties.contentType += " audio/mpeg";
+        properties.contentTypes << "audio/mpeg";
     if(filters.contains("*.aac"))
-        properties.contentType += " audio/aac audio/aacp";
-    if(filters.contains("*.m4a"))
-        properties.contentType += " audio/x-ffmpeg-shorten";
+        properties.contentTypes << "audio/aac" << "audio/aacp";
     if(filters.contains("*.shn"))
-        properties.contentType += " audio/3gpp audio/3gpp2 audio/mp4 audio/MP4A-LATM audio/mpeg4-generic";
-    properties.contentType = properties.contentType.trimmed();
+        properties.contentTypes << "audio/x-ffmpeg-shorten";
+    if(filters.contains("*.m4a"))
+    {
+        properties.contentTypes << "audio/3gpp" << "audio/3gpp2" << "audio/mp4";
+        properties.contentTypes << "audio/MP4A-LATM" << "audio/mpeg4-generic";
+        properties.contentTypes << "audio/m4a";
+    }
+    if(filters.contains("*.ac3"))
+        properties.contentTypes << "audio/ac3";
     properties.shortName = "ffmpeg";
     properties.hasAbout = true;
     properties.hasSettings = true;
@@ -162,13 +130,40 @@ QList<FileInfo *> DecoderFFmpegFactory::createPlayList(const QString &fileName,
 
     if (useMetaData)
     {
-        info->setMetaData(Qmmp::ALBUM, QString::fromUtf8(in->album).trimmed());
-        info->setMetaData(Qmmp::ARTIST, QString::fromUtf8(in->author).trimmed());
-        info->setMetaData(Qmmp::COMMENT, QString::fromUtf8(in->comment).trimmed());
-        info->setMetaData(Qmmp::GENRE, QString::fromUtf8(in->genre).trimmed());
-        info->setMetaData(Qmmp::TITLE, QString::fromUtf8(in->title).trimmed());
-        info->setMetaData(Qmmp::YEAR, in->year);
-        info->setMetaData(Qmmp::TRACK, in->track);
+        AVMetadataTag *album = av_metadata_get(in->metadata,"album",0,0);
+        if(!album)
+            album = av_metadata_get(in->metadata,"WM/AlbumTitle",0,0);
+        AVMetadataTag *artist = av_metadata_get(in->metadata,"artist",0,0);
+        if(!artist)
+            artist = av_metadata_get(in->metadata,"author",0,0);
+        AVMetadataTag *comment = av_metadata_get(in->metadata,"comment",0,0);
+        AVMetadataTag *genre = av_metadata_get(in->metadata,"genre",0,0);
+        AVMetadataTag *title = av_metadata_get(in->metadata,"title",0,0);
+        AVMetadataTag *year = av_metadata_get(in->metadata,"WM/Year",0,0);
+        if(!year)
+            year = av_metadata_get(in->metadata,"year",0,0);
+        if(!year)
+            year = av_metadata_get(in->metadata,"date",0,0);
+        AVMetadataTag *track = av_metadata_get(in->metadata,"track",0,0);
+        if(!track)
+            track = av_metadata_get(in->metadata,"WM/Track",0,0);
+        if(!track)
+            track = av_metadata_get(in->metadata,"WM/TrackNumber",0,0);
+
+        if(album)
+            info->setMetaData(Qmmp::ALBUM, QString::fromUtf8(album->value).trimmed());
+        if(artist)
+            info->setMetaData(Qmmp::ARTIST, QString::fromUtf8(artist->value).trimmed());
+        if(comment)
+            info->setMetaData(Qmmp::COMMENT, QString::fromUtf8(comment->value).trimmed());
+        if(genre)
+            info->setMetaData(Qmmp::GENRE, QString::fromUtf8(genre->value).trimmed());
+        if(title)
+            info->setMetaData(Qmmp::TITLE, QString::fromUtf8(title->value).trimmed());
+        if(year)
+            info->setMetaData(Qmmp::YEAR, year->value);
+        if(track)
+            info->setMetaData(Qmmp::TRACK, track->value);
     }
     info->setLength(in->duration/AV_TIME_BASE);
     av_close_input_file(in);
@@ -201,7 +196,7 @@ void DecoderFFmpegFactory::showAbout(QWidget *parent)
                         .arg(LIBAVCODEC_VERSION_MINOR)
                         .arg(LIBAVCODEC_VERSION_MICRO)+"\n"+
 #endif
-                        tr("Writen by: Ilya Kotov <forkotov02@hotmail.ru>"));
+                        tr("Written by: Ilya Kotov <forkotov02@hotmail.ru>"));
 }
 
 QTranslator *DecoderFFmpegFactory::createTranslator(QObject *parent)
