@@ -20,6 +20,8 @@
  ***************************************************************************/
 
 #include <QApplication>
+#include <QSettings>
+#include <QDir>
 
 extern "C"
 {
@@ -30,61 +32,29 @@ extern "C"
 #endif
 }
 
-#include "outputoss.h"
-#include <qmmp/buffer.h>
-#include <qmmp/visual.h>
-
 #include <stdio.h>
 #include <string.h>
-#include <QtGlobal>
-#include <QSettings>
-#include <QDir>
-
+#include <errno.h>
 #include <iostream>
-
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/ioctl.h>
 #include <sys/time.h>
+#include <qmmp/buffer.h>
+#include <qmmp/visual.h>
+#include "outputoss.h"
 
-#if defined(__FreeBSD__)
-#  include <sys/soundcard.h>
-#elif defined(__linux__)
-#  include <linux/soundcard.h>
-#elif defined(__bsdi__)
-#  include <sys/soundcard.h>
-#endif
-
-OutputOSS *OutputOSS::m_instance = 0;
-VolumeControlOSS *VolumeControlOSS::m_instance = 0;
-
-OutputOSS* OutputOSS::instance()
-{
-    return m_instance;
-}
-
-OutputOSS::OutputOSS(QObject * parent)
-        : Output(parent), m_inited(false),
-         m_frequency(-1), m_channels(-1),
-        do_select(true),
-        m_audio_fd(-1)
+OutputOSS::OutputOSS(QObject * parent) : Output(parent), do_select(true), m_audio_fd(-1)
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     m_audio_device = settings.value("OSS/device","/dev/dsp").toString();
-    m_instance = this;
-}
-
-int OutputOSS::audio_fd()
-{
-    return m_audio_fd;
 }
 
 OutputOSS::~OutputOSS()
 {
-     m_instance = 0;
-    if (m_audio_fd > 0)
+    if (m_audio_fd >= 0)
     {
-        resetDSP();
+        ioctl(m_audio_fd, SNDCTL_DSP_RESET, 0);
         close(m_audio_fd);
         m_audio_fd = -1;
     }
@@ -92,76 +62,74 @@ OutputOSS::~OutputOSS()
 
 void OutputOSS::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
 {
-    // we need to configure
-    if (freq != m_frequency || chan != m_channels)
+    int p;
+    switch (format)
     {
-        // we have already configured, but are changing settings...
-        // reset the device
-        resetDSP();
-#if SOUND_VERSION >= 0x040000
-    if (VolumeControlOSS::instance())
+    case Qmmp::PCM_S16LE:
+        p = AFMT_S16_LE;
+        break;
+    case Qmmp::PCM_S8:
+        p = AFMT_S8;
+        break;
+    default:
+        qWarning("OutputOSS: unsupported audio format");
+        return;
+    }
+    int param = p;
+    if (ioctl(m_audio_fd, SNDCTL_DSP_SETFMT, &p) < 0)
     {
-        long cmd;
-        int v;
-        cmd = SNDCTL_DSP_SETPLAYVOL;
-        v = (VolumeControlOSS::instance()->right() << 8) | VolumeControlOSS::instance()->left();
-        if(m_audio_fd > 1)
-            ioctl(m_audio_fd, cmd, &v);
+        qWarning("OutputOSS: ioctl SNDCTL_DSP_SETFMT failed: %s",strerror(errno));
+        return;
     }
-#endif
-        m_frequency = freq;
-        m_channels = chan;
-
-        //m_bps = freq * chan * (prec / 8);
-
-        int p;
-        switch (format)
-        {
-        default:
-        case Qmmp::PCM_S16LE:
-#if defined(AFMT_S16_NE)
-            p = AFMT_S16_NE;
-#else
-            p = AFMT_S16_LE;
-#endif
-            break;
-
-        case Qmmp::PCM_S8:
-            p = AFMT_S8;
-            break;
-
-        }
-
-        if (ioctl(m_audio_fd, SNDCTL_DSP_SETFMT, &p) == -1)
-            qWarning("OutputOSS: can't set audio format");
-        /*if(ioctl(m_audio_fd, SNDCTL_DSP_SAMPLESIZE, &prec) == -1)
-            qDebug("OutputOSS: can't set audio format");*/
-        int stereo = (chan > 1) ? 1 : 0;
-            ioctl(m_audio_fd, SNDCTL_DSP_STEREO, &stereo);
-        /*if (ioctl(m_audio_fd, SNDCTL_DSP_SPEED, &m_channels) == -1)
-            qWarning("OutputOSS: can't set number of channels");*/
-        /*if (chan != m_channels)
-            qWarning("OutputOSS: can't set number of channels, using %d instead", m_channels);*/
-        if (ioctl(m_audio_fd, SNDCTL_DSP_SPEED, &freq) == -1)
-            qWarning("OutputOSS: can't set audio format");
+    if(param != p)
+    {
+        qWarning("OutputOSS: unsupported audio format");
+        return;
     }
+    param = chan;
+    if(ioctl(m_audio_fd, SNDCTL_DSP_CHANNELS, &chan) < 0)
+    {
+        qWarning("OutputOSS: ioctl SNDCTL_DSP_CHANNELS failed: %s", strerror(errno));
+        return;
+    }
+    if(param != chan)
+    {
+        qWarning("OutputOSS: unsupported %d-channel mode", param);
+        return;
+    }
+    uint param2 = freq;
+    if (ioctl(m_audio_fd, SNDCTL_DSP_SPEED, &freq) < 0)
+    {
+        qWarning("OutputOSS: ioctl SNDCTL_DSP_SPEED failed: %s", strerror(errno));
+        return;
+    }
+    if(param2 != freq)
+    {
+        qWarning("OutputOSS: unsupported sample rate");
+        return;
+    }
+    ioctl(m_audio_fd, SNDCTL_DSP_RESET, 0);
     Output::configure(freq, chan, format);
 }
 
-void OutputOSS::reset()
+void OutputOSS::post()
 {
-    if (m_audio_fd > 0)
-    {
-        close(m_audio_fd);
-        m_audio_fd = -1;
-    }
+    ioctl(m_audio_fd, SNDCTL_DSP_POST, 0);
+}
 
+void OutputOSS::sync()
+{
+    ioctl(m_audio_fd, SNDCTL_DSP_SYNC, 0);
+}
+
+bool OutputOSS::initialize()
+{
     m_audio_fd = open(m_audio_device.toAscii(), O_WRONLY, 0);
 
     if (m_audio_fd < 0)
     {
         qWarning("OSSOutput: failed to open output device '%s'", qPrintable(m_audio_device));
-        return;
+        return false;
     }
 
     int flags;
@@ -170,7 +138,6 @@ void OutputOSS::reset()
         flags &= O_NDELAY;
         fcntl(m_audio_fd, F_SETFL, flags);
     }
-
     fd_set afd;
     FD_ZERO(&afd);
     FD_SET(m_audio_fd, &afd);
@@ -178,62 +145,9 @@ void OutputOSS::reset()
     tv.tv_sec = 0l;
     tv.tv_usec = 50000l;
     do_select = (select(m_audio_fd + 1, 0, &afd, 0, &tv) > 0);
-}
-
-void OutputOSS::post()
-{
-    if (m_audio_fd < 1)
-        return;
-
-    int unused;
-    ioctl(m_audio_fd, SNDCTL_DSP_POST, &unused);
-}
-
-void OutputOSS::sync()
-{
-    if (m_audio_fd < 1)
-        return;
-
-    int unused;
-    ioctl(m_audio_fd, SNDCTL_DSP_SYNC, &unused);
-}
-
-
-void OutputOSS::resetDSP()
-{
-    if (m_audio_fd < 1)
-        return;
-
-    int unused;
-    ioctl(m_audio_fd, SNDCTL_DSP_RESET, &unused);
-}
-
-
-bool OutputOSS::initialize()
-{
-    reset();
-    if (m_audio_fd < 0)
-        return false;
-    m_inited = true;
     return true;
 }
 
-void OutputOSS::uninitialize()
-{
-    if (!m_inited)
-        return;
-    m_inited = false;
-    m_frequency = -1;
-    m_channels = -1;
-    resetDSP();
-    if (m_audio_fd > 0)
-    {
-        close(m_audio_fd);
-        m_audio_fd = -1;
-    }
-    qDebug("OutputOSS: uninitialize");
-}
-
 qint64 OutputOSS::latency()
 {
     //ulong used = 0;
@@ -253,7 +167,7 @@ qint64 OutputOSS::writeAudio(unsigned char *data, qint64 maxSize)
     // nice long poll timeout
     tv.tv_sec = 5l;
     tv.tv_usec = 0l;
-    if ((! do_select || (select(m_audio_fd + 1, 0, &afd, 0, &tv) > 0 &&
+    if ((!do_select || (select(m_audio_fd + 1, 0, &afd, 0, &tv) > 0 &&
                                  FD_ISSET(m_audio_fd, &afd))))
     {
         l = qMin(int(2048), int(maxSize));
@@ -266,73 +180,42 @@ qint64 OutputOSS::writeAudio(unsigned char *data, qint64 maxSize)
     return m;
 }
 
-/***** MIXER *****/
-
-VolumeControlOSS *VolumeControlOSS::instance()
+void OutputOSS::drain()
 {
-    return m_instance;
+    ioctl(m_audio_fd, SNDCTL_DSP_SYNC, 0);
 }
 
+void OutputOSS::reset()
+{
+    ioctl(m_audio_fd, SNDCTL_DSP_RESET, 0);
+}
+
+/***** MIXER *****/
 VolumeControlOSS::VolumeControlOSS(QObject *parent) : VolumeControl(parent)
 {
     m_master = true;
     m_mixer_fd = -1;
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-#if SOUND_VERSION < 0x040000
     m_mixer_device = settings.value("OSS/mixer_device","/dev/mixer").toString();
     openMixer();
-#else
-    m_mixer_device = settings.value("OSS/device","/dev/dsp").toString();
-    int mixer_fd = -1;
-    bool to_close = false;
-    if (OutputOSS::instance() && OutputOSS::instance()->audio_fd() > 0)
-        mixer_fd = OutputOSS::instance()->audio_fd();
-    else
-    {
-        mixer_fd = open(m_audio_device.toAscii(), O_WRONLY, 0);
-        to_close = true;
-    }
-    if(mixer_fd > 0)
-    {
-        int v;
-        long cmd = SNDCTL_DSP_GETPLAYVOL;
-        if (ioctl(mixer_fd, cmd, &v) == -1)
-            v = 0;
-        m_left2 = (v & 0xFF00) >> 8;
-        m_right2 = (v & 0x00FF);
-    }
-    if(to_close)
-    {
-        close(mixer_fd);
-            mixer_fd = -1;
-    }
-#endif
-    m_instance = this;
+
 }
 
 VolumeControlOSS::~VolumeControlOSS()
 {
-#if SOUND_VERSION < 0x040000
-    if (m_mixer_fd > 0)
+    if (m_mixer_fd >= 0)
     {
         close(m_mixer_fd);
         m_mixer_fd = -1;
     }
-#endif
-    if (m_mixer_fd > 0 && !OutputOSS::instance())
-    {
-        close(m_mixer_fd);
-        m_mixer_fd = -1;
-    }
-    m_instance = 0;
 }
 
 void VolumeControlOSS::setVolume(int l, int r)
 {
+    if (m_mixer_fd < 0)
+        return;
     int v;
     long cmd;
-
-#if SOUND_VERSION < 0x040000
     int devs = 0;
     ioctl(m_mixer_fd, SOUND_MIXER_READ_DEVMASK, &devs);
     if ((devs & SOUND_MASK_PCM) && !m_master)
@@ -346,22 +229,15 @@ void VolumeControlOSS::setVolume(int l, int r)
     }
     v = (r << 8) | l;
     ioctl(m_mixer_fd, cmd, &v);
-#else
-    cmd = SNDCTL_DSP_SETPLAYVOL;
-    v = (r << 8) | l;
-    if (OutputOSS::instance() && OutputOSS::instance()->audio_fd() > 0)
-        ioctl(OutputOSS::instance()->audio_fd(), cmd, &v);
-    m_left2 = l;
-    m_right2 = r;
-#endif
 }
 
 void VolumeControlOSS::volume(int *ll,int *rr)
 {
     *ll = 0;
     *rr = 0;
-#if SOUND_VERSION < 0x040000
-    int  cmd;
+    if(m_mixer_fd < 0)
+        return;
+    int cmd;
     int v, devs = 0;
     ioctl(m_mixer_fd, SOUND_MIXER_READ_DEVMASK, &devs);
     if ((devs & SOUND_MASK_PCM) && !m_master)
@@ -380,21 +256,11 @@ void VolumeControlOSS::volume(int *ll,int *rr)
     *rr = (*rr > 100) ? 100 : *rr;
     *ll = (*ll < 0) ? 0 : *ll;
     *rr = (*rr < 0) ? 0 : *rr;
-#else
-    /*cmd = SNDCTL_DSP_GETPLAYVOL;
-    if (ioctl(m_audio_fd, cmd, &v) == -1)
-        v = 0;
-    *rr = (v & 0xFF00) >> 8;
-    *ll = (v & 0x00FF);*/
-    *rr = m_left2;
-    *ll = m_right2;
-#endif
 }
 
 void VolumeControlOSS::openMixer()
 {
-#if SOUND_VERSION < 0x040000
-    if (m_mixer_fd != -1)
+    if (m_mixer_fd >= 0)
         return;
     m_mixer_fd = open(m_mixer_device.toAscii(), O_RDWR);
     if (m_mixer_fd < 0)
@@ -402,5 +268,4 @@ void VolumeControlOSS::openMixer()
         qWarning("VolumeControlOSS: unable to open mixer device '%s'", qPrintable(m_mixer_device));
         return;
     }
-#endif
 }
