@@ -4,7 +4,7 @@
 <context>
     <name>Analyzer</name>
     <message>
-        <location filename="../analyzer.cpp" line="48"/>
+        <location filename="../analyzer.cpp" line="51"/>
         <source>Qmmp Analyzer</source>
         <translation>Qmmp 可視化解析器</translation>
     </message>
@@ -141,7 +141,7 @@
     </message>
     <message>
         <location filename="../visualanalyzerfactory.cpp" line="51"/>
-        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
