@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2011 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,21 +33,14 @@
 #include "qmmpaudioengine.h"
 #include "metadatamanager.h"
 
-extern "C"
-{
-#include "equ/iir.h"
-}
 
 QmmpAudioEngine::QmmpAudioEngine(QObject *parent)
-        : AbstractEngine(parent), m_factory(0), m_output(0), m_eqInited(false),
-        m_useEq(false), m_eqEnabled(false)
+        : AbstractEngine(parent), m_factory(0), m_output(0)
 {
-    m_output_buf = new unsigned char[QMMP_BUFFER_SIZE];
-    double b[] = {0,0,0,0,0,0,0,0,0,0};
-    setEQ(b, 0);
     qRegisterMetaType<Qmmp::State>("Qmmp::State");
-    m_effects = Effect::create();
-    m_bks = QMMP_BLOCK_SIZE;
+    m_output_buf = 0;
+    m_output_size = 0;
+    m_bks = 0;
     m_decoder = 0;
     m_output = 0;
     m_replayGain = new ReplayGain;
@@ -90,7 +83,8 @@ bool QmmpAudioEngine::play()
         return false;
     if(m_output)
         delete m_output;
-    if(!(m_output = createOutput(m_decoders.head())))
+    prepareEffects(m_decoders.head());
+    if(!(m_output = createOutput()))
         return false;
     start();
     return true;
@@ -150,29 +144,6 @@ qint64 QmmpAudioEngine::totalTime()
         return 0;
 }
 
-void QmmpAudioEngine::setEQ(double bands[10], double preamp)
-{
-    mutex()->lock();
-    set_preamp(0, 1.0 + 0.0932471 *preamp + 0.00279033 * preamp * preamp);
-    set_preamp(1, 1.0 + 0.0932471 *preamp + 0.00279033 * preamp * preamp);
-    for (int i=0; i<10; ++i)
-    {
-        double value = bands[i];
-        set_gain(i,0, 0.03*value+0.000999999*value*value);
-        set_gain(i,1, 0.03*value+0.000999999*value*value);
-    }
-    mutex()->unlock();
-}
-
-void QmmpAudioEngine::setEQEnabled(bool on)
-{
-    mutex()->lock();
-    m_eqEnabled = on;
-    if(m_decoder)
-        m_useEq = m_eqEnabled && m_decoder->audioParameters().format() == Qmmp::PCM_S16LE;
-    mutex()->unlock();
-}
-
 void QmmpAudioEngine::addEffect(EffectFactory *factory)
 {
     foreach(Effect *effect, m_effects)
@@ -186,8 +157,9 @@ void QmmpAudioEngine::addEffect(EffectFactory *factory)
     }
     if(m_output && m_output->isRunning())
     {
-        Effect *effect = factory->create();
-        effect->setFactory(factory);
+        Effect *effect = Effect::create(factory);
+        if(!effect)
+            return;
         effect->configure(m_ap.sampleRate(), m_ap.channels(), m_ap.format());
         if(effect->audioParameters() == m_ap)
         {
@@ -197,7 +169,7 @@ void QmmpAudioEngine::addEffect(EffectFactory *factory)
         }
         else
         {
-            qDebug("QmmpAudioEngine: restart required");
+            qDebug("QmmpAudioEngine: restart is required");
             delete effect;
         }
     }
@@ -220,7 +192,7 @@ void QmmpAudioEngine::removeEffect(EffectFactory *factory)
     {
         mutex()->lock();
         if(m_blockedEffects.contains(effect))
-            qDebug("QmmpAudioEngine: restart required");
+            qDebug("QmmpAudioEngine: restart is required");
         else
             m_effects.removeAll(effect);
         mutex()->unlock();
@@ -232,7 +204,7 @@ void QmmpAudioEngine::seek(qint64 time)
     if (m_output && m_output->isRunning())
     {
         m_output->mutex()->lock ();
-        m_output->seek(time);
+        m_output->seek(time, true);
         m_output->mutex()->unlock();
         if (isRunning())
         {
@@ -246,11 +218,8 @@ void QmmpAudioEngine::seek(qint64 time)
 void QmmpAudioEngine::pause()
 {
     if (m_output)
-    {
-        m_output->mutex()->lock ();
         m_output->pause();
-        m_output->mutex()->unlock();
-    }
+
 
     // wake up threads
     if (m_decoder)
@@ -296,11 +265,10 @@ void QmmpAudioEngine::stop()
     }
 
     wait();
-    if (m_output)
-        m_output->wait();
 
     if (m_output)
     {
+        m_output->wait();
         delete m_output;
         m_output = 0;
     }
@@ -317,22 +285,11 @@ void QmmpAudioEngine::stop()
         delete m_effects.takeFirst();
 }
 
-qint64 QmmpAudioEngine::produceSound(char *data, qint64 size, quint32 brate, int chan)
+qint64 QmmpAudioEngine::produceSound(char *data, qint64 size, quint32 brate)
 {
+    Buffer *b = m_output->recycler()->get();
     uint sz = size < m_bks ? size : m_bks;
     m_replayGain->applyReplayGain(data, sz);
-    if (m_useEq && m_decoder->audioParameters().format() == Qmmp::PCM_S16LE)
-    {
-        if (!m_eqInited)
-        {
-            init_iir();
-            m_eqInited = true;
-        }
-        iir((void*) data, sz, chan);
-    }
-
-    Buffer *b = m_output->recycler()->get();
-
     memcpy(b->data, data, sz);
     b->nbytes = sz;
     b->rate = brate;
@@ -340,9 +297,9 @@ qint64 QmmpAudioEngine::produceSound(char *data, qint64 size, quint32 brate, int
     {
         effect->applyEffect(b);
     }
-    m_output->recycler()->add();
     size -= sz;
     memmove(data, data + sz, size);
+    m_output->recycler()->add();
     return sz;
 }
 
@@ -401,8 +358,7 @@ void QmmpAudioEngine::run()
             m_output_at = 0;
         }
 
-        len = m_decoder->read((char *)(m_output_buf + m_output_at),
-                              QMMP_BUFFER_SIZE - m_output_at);
+        len = m_decoder->read((char *)(m_output_buf + m_output_at), m_output_size - m_output_at);
 
         if (len > 0)
         {
@@ -435,7 +391,8 @@ void QmmpAudioEngine::run()
                 //m_seekTime = m_inputs.value(m_decoder)->offset();
                 m_replayGain->setReplayGainInfo(m_decoder->replayGainInfo());
                 //use current output if possible
-                if(m_decoder->audioParameters() == m_ap)
+                prepareEffects(m_decoder);
+                if(m_ap == m_output->audioParameters())
                 {
                     emit playbackFinished();
                     StateHandler::instance()->dispatch(Qmmp::Stopped); //fake stop/start cycle
@@ -460,7 +417,7 @@ void QmmpAudioEngine::run()
 
                     m_output->wait();
                     delete m_output;
-                    m_output = createOutput(m_decoder);
+                    m_output = createOutput();
                     if(m_output)
                     {
                         m_output->start();
@@ -514,16 +471,15 @@ void QmmpAudioEngine::flush(bool final)
     while ((!m_done && !m_finish) && m_output_at > min)
     {
         m_output->recycler()->mutex()->lock ();
-        if(m_seekTime >= 0)
-        {
-            m_output->recycler()->clear();
-            m_output->recycler()->mutex()->unlock ();
-            m_output_at = 0;
-            break;
-        }
 
         while ((m_output->recycler()->full() || m_output->recycler()->blocked()) && (!m_done && !m_finish))
         {
+            if(m_seekTime > 0)
+            {
+                m_output_at = 0;
+                m_output->recycler()->mutex()->unlock ();
+                return;
+            }
             mutex()->unlock();
             m_output->recycler()->cond()->wait(m_output->recycler()->mutex());
             mutex()->lock ();
@@ -534,10 +490,10 @@ void QmmpAudioEngine::flush(bool final)
             m_done = true;
         else
         {
-            m_output_at -= produceSound((char*)m_output_buf, m_output_at, m_bitrate, m_chan);
+            m_output_at -= produceSound((char*)m_output_buf, m_output_at, m_bitrate);
         }
 
-        if (m_output->recycler()->full())
+        if (!m_output->recycler()->empty())
         {
             m_output->recycler()->cond()->wakeOne();
         }
@@ -573,13 +529,8 @@ void QmmpAudioEngine::sendMetaData()
     }
 }
 
-Output *QmmpAudioEngine::createOutput(Decoder *d)
+Output *QmmpAudioEngine::createOutput()
 {
-    m_blockedEffects.clear();
-    while(!m_effects.isEmpty()) //delete effects
-        delete m_effects.takeFirst();
-
-    m_ap = d->audioParameters();
     Output *output = Output::create(0);
     if(!output)
     {
@@ -595,31 +546,72 @@ Output *QmmpAudioEngine::createOutput(Decoder *d)
         StateHandler::instance()->dispatch(Qmmp::FatalError);
         return false;
     }
-    m_effects = Effect::create();
-    AudioParameters ap = m_ap;
-    m_replayGain->setSampleSize(m_ap.sampleSize());
-    if(!m_eqInited)
-    {
-        init_iir();
-        m_eqInited = true;
-    }
-    m_useEq = m_eqEnabled && ap.format() == Qmmp::PCM_S16LE;
+    output->configure(m_ap.sampleRate(), m_ap.channels(), m_ap.format());
+    if(m_output_buf)
+        delete [] m_output_buf;
+    m_bks = QMMP_BLOCK_FRAMES * m_ap.channels() * m_ap.sampleSize();
+    m_output_size = m_bks * 4;
+    m_output_buf = new unsigned char[m_output_size];
+    return output;
+}
 
-    if(m_settings->use16BitOutput())
-        m_effects.prepend (new AudioConverter());
+void QmmpAudioEngine::prepareEffects(Decoder *d)
+{
+    m_ap = d->audioParameters();
 
-    foreach(Effect *effect, m_effects)
+    foreach(Effect *e, m_effects) //remove disabled and external effects
     {
-        effect->configure(ap.sampleRate(), ap.channels(), ap.format());
-        if (ap != effect->audioParameters())
+        if(!e->factory() || !Effect::isEnabled(e->factory()))
         {
-            m_blockedEffects << effect; //list of effects which require restart
-            ap = effect->audioParameters();
+            m_effects.removeAll(e);
+            m_blockedEffects.removeAll(e);
+            delete e;
         }
     }
-    m_chan = ap.channels();
-    output->configure(ap.sampleRate(), ap.channels(), ap.format());
-    return output;
+    QList <Effect *> m_tmp_effects = m_effects;
+    m_effects.clear();
+
+    if(m_settings->use16BitOutput())
+    {
+        m_effects << new AudioConverter();
+        m_effects.at(0)->configure(m_ap.sampleRate(), m_ap.channels(), m_ap.format());
+        m_ap = m_effects.at(0)->audioParameters();
+    }
+
+    foreach(EffectFactory *factory, *Effect::factories())
+    {
+        if(!Effect::isEnabled(factory))
+            continue;
+
+        Effect *effect = 0;
+        foreach(Effect *e, m_tmp_effects) //find effect
+        {
+            if(e->factory() == factory)
+                effect = e;
+        }
+
+        if(effect && (effect->audioParameters() != m_ap ||
+                      m_blockedEffects.contains(effect))) //destroy effect which require restart
+        {
+            m_blockedEffects.removeAll(effect);
+            m_tmp_effects.removeAll(effect);
+            delete effect;
+            effect = 0;
+        }
+        if(!effect)
+        {
+            effect = Effect::create(factory);
+            effect->configure(m_ap.sampleRate(), m_ap.channels(), m_ap.format());
+            if (m_ap != effect->audioParameters())
+            {
+                m_blockedEffects << effect; //list of effects which require restart
+                m_ap = effect->audioParameters();
+            }
+        }
+        m_effects << effect;
+        m_tmp_effects.removeAll(effect);
+    }
+    m_chan = m_ap.channels();
 }
 
 //static members
