@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2011 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -41,18 +41,11 @@ SoundCore::SoundCore(QObject *parent)
 {
     m_instance = this;
     m_decoder = 0;
-    m_paused = false;
-    m_useEQ = false;
-    m_update = false;
-    m_block = false;
-    m_preamp = 0;
-    m_vis = 0;
+    m_error = false;
     m_parentWidget = 0;
     m_engine = 0;
     m_pendingEngine = 0;
     m_volumeControl = 0;
-    for (int i = 1; i < 10; ++i)
-        m_bands[i] = 0;
     m_handler = new StateHandler(this);
     connect(m_handler, SIGNAL(elapsedChanged(qint64)), SIGNAL(elapsedChanged(qint64)));
     connect(m_handler, SIGNAL(bitrateChanged(int)), SIGNAL(bitrateChanged(int)));
@@ -62,13 +55,13 @@ SoundCore::SoundCore(QObject *parent)
     connect(m_handler, SIGNAL(metaDataChanged ()), SIGNAL(metaDataChanged ()));
     connect(m_handler, SIGNAL(stateChanged (Qmmp::State)), SIGNAL(stateChanged(Qmmp::State)));
     connect(m_handler, SIGNAL(stateChanged (Qmmp::State)), SLOT(startPendingEngine()));
-    connect(m_handler, SIGNAL(aboutToFinish()), SIGNAL(aboutToFinish()));
+    connect(m_handler, SIGNAL(nextTrackRequest()), SIGNAL(nextTrackRequest()));
     connect(m_handler, SIGNAL(bufferingProgress(int)), SIGNAL(bufferingProgress(int)));
     updateVolume();
+    connect(QmmpSettings::instance(), SIGNAL(eqSettingsChanged()), SIGNAL(eqSettingsChanged()));
     connect(QmmpSettings::instance(), SIGNAL(audioSettingsChanged()), SLOT(updateVolume()));
 }
 
-
 SoundCore::~SoundCore()
 {
     stop();
@@ -78,9 +71,14 @@ SoundCore::~SoundCore()
 bool SoundCore::play(const QString &source, bool queue, qint64 offset)
 {
     if(!queue)
-    {
         stop();
-        qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
+    else
+    {
+        qDeleteAll(m_pendingSources);
+        m_pendingSources.clear();
+        if(m_pendingEngine)
+            delete m_pendingEngine;
+        m_pendingEngine = 0;
     }
     MetaDataManager::instance(); //create metadata manager
 
@@ -89,7 +87,8 @@ bool SoundCore::play(const QString &source, bool queue, qint64 offset)
     m_pendingSources.append(s);
     if(state() == Qmmp::Stopped)
         m_handler->dispatch(Qmmp::Buffering);
-    connect(s, SIGNAL(ready(InputSource *)), SLOT(enqueue(InputSource *)));
+    connect(s, SIGNAL(ready()), SLOT(enqueue()));
+    connect(s, SIGNAL(error()), SLOT(enqueue()));
     bool ok = s->initialize();
     if(!ok)
     {
@@ -104,13 +103,16 @@ bool SoundCore::play(const QString &source, bool queue, qint64 offset)
 void SoundCore::stop()
 {
     m_url.clear();
-    if(m_engine)
-        m_engine->stop();
-    qDeleteAll(m_pendingSources);
-    m_pendingSources.clear();
     if(m_pendingEngine)
         delete m_pendingEngine;
     m_pendingEngine = 0;
+    if(m_engine)
+    {
+        m_engine->stop();
+        qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
+    }
+    qDeleteAll(m_pendingSources);
+    m_pendingSources.clear();
     updateVolume();
     if(state() == Qmmp::NormalError || state() == Qmmp::FatalError || state() == Qmmp::Buffering)
         StateHandler::instance()->dispatch(Qmmp::Stopped); //clear error and buffering state
@@ -138,26 +140,14 @@ qint64 SoundCore::totalTime() const
     return  (m_engine) ? m_engine->totalTime() : 0;
 }
 
-void SoundCore::setEQ(double bands[10], double preamp)
+EqSettings SoundCore::eqSettings() const
 {
-    for (int i = 0; i < 10; ++i)
-        m_bands[i] = bands[i];
-    m_preamp = preamp;
-    if (m_engine)
-    {
-        m_engine->setEQ(m_bands, m_preamp);
-        m_engine->setEQEnabled(m_useEQ);
-    }
+    return QmmpSettings::instance()->eqSettings();
 }
 
-void SoundCore::setEQEnabled(bool on)
+void SoundCore::setEqSettings(const EqSettings &settings)
 {
-    m_useEQ = on;
-    if (m_engine)
-    {
-        m_engine->setEQ(m_bands, m_preamp);
-        m_engine->setEQEnabled(on);
-    }
+    QmmpSettings::instance()->setEqSettings(settings);
 }
 
 void SoundCore::setVolume(int L, int R)
@@ -191,32 +181,32 @@ void SoundCore::updateVolume()
 
 qint64 SoundCore::elapsed()
 {
-    return  m_handler->elapsed();
+    return m_handler->elapsed();
 }
 
 int SoundCore::bitrate()
 {
-    return  m_handler->bitrate();
+    return m_handler->bitrate();
 }
 
 quint32 SoundCore::frequency()
 {
-    return  m_handler->frequency();
+    return m_handler->frequency();
 }
 
 int SoundCore::precision() //TODO rename
 {
-    return  m_handler->precision();
+    return m_handler->precision();
 }
 
 int SoundCore::channels()
 {
-    return  m_handler->channels();
+    return m_handler->channels();
 }
 
 Qmmp::State SoundCore::state() const
 {
-    return  m_handler->state();
+    return m_handler->state();
 }
 
 QMap <Qmmp::MetaData, QString> SoundCore::metaData()
@@ -229,65 +219,89 @@ QString SoundCore::metaData(Qmmp::MetaData key)
     return m_handler->metaData(key);
 }
 
-bool SoundCore::enqueue(InputSource *s)
+bool SoundCore::enqueue()
 {
-    m_pendingSources.removeAll(s);
-    m_url = s->url();
-    if(!m_engine)
+    InputSource *s = qobject_cast<InputSource*>(sender());
+    if(!s)
     {
-        m_engine = new QmmpAudioEngine(this);
-        connect(m_engine, SIGNAL(playbackFinished()), SIGNAL(finished()));
+        qWarning("SoundCore: unknown signal source");
+        return false;
+    }
+
+    m_pendingSources.removeAll(s);
+    m_url = s->url();
+
+    if(s->ioDevice())
+    {
+        bool ok = s->ioDevice()->open(QIODevice::ReadOnly);
+        if(!ok)
+        {
+            qWarning("SoundCore: input error: %s", qPrintable(s->ioDevice()->errorString()));
+            m_url.clear();
+            s->deleteLater();
+            if(state() == Qmmp::Stopped || state() == Qmmp::Buffering)
+            {
+                m_handler->dispatch(Qmmp::NormalError);
+            }
+            else
+                m_error = true;
+            return false;
+        }
+    }
+
+    if(!m_engine)
+    {
+        if((m_engine = AbstractEngine::create(s, this)))
+        {
+            connect(m_engine, SIGNAL(playbackFinished()), SIGNAL(finished()));
+            m_engine->play();
+            m_handler->setCurrentEngine(m_engine);
+            return true;
+        }
+        else
+        {
+            s->deleteLater();
+            m_handler->setCurrentEngine(0);
+            m_handler->dispatch(Qmmp::NormalError);
+            return false;
+        }
     }
 
-    setEQ(m_bands, m_preamp);
-    setEQEnabled(m_useEQ);
     if(m_engine->enqueue(s))
     {
         if(state() == Qmmp::Stopped || state() == Qmmp::Buffering)
             m_engine->play();
+        else
+            m_handler->setNextEngine(m_engine);
+        m_handler->setCurrentEngine(m_engine);
     }
     else
     {
-        //current engine doesn't support this stream, trying to find another
-        AbstractEngine *engine = new QmmpAudioEngine(this); //internal engine
-        if(!engine->enqueue(s))
-        {
-            engine->deleteLater();
-            engine = 0;
-        }
-
+        AbstractEngine *engine = AbstractEngine::create(s, this);
         if(!engine)
-        {
-            foreach(EngineFactory *f, *AbstractEngine::factories())
-            {
-                engine = f->create(this); //engine plugin
-                if(!engine->enqueue(s))
-                {
-                    engine->deleteLater();
-                    engine = 0;
-                }
-            }
-        }
-
-        if(!engine) //unsupported file format
         {
             s->deleteLater();
+            m_handler->setCurrentEngine(0);
+            if(state() == Qmmp::Stopped || state() == Qmmp::Buffering)
+                m_handler->dispatch(Qmmp::NormalError);
+            else
+                m_error = true;
             return false;
         }
         connect(engine, SIGNAL(playbackFinished()), SIGNAL(finished()));
-        engine->setEQ(m_bands, m_preamp);
-        engine->setEQEnabled(m_useEQ);
         if (m_handler->state() == Qmmp::Playing || m_handler->state() == Qmmp::Paused)
         {
             if(m_pendingEngine)
                 m_pendingEngine->deleteLater();
             m_pendingEngine = engine;
+            m_handler->setNextEngine(engine);
         }
         else
         {
             m_engine->deleteLater();
             m_engine = engine;
             m_engine->play();
+            m_handler->setCurrentEngine(m_engine);
             m_pendingEngine = 0;
         }
     }
@@ -303,6 +317,12 @@ void SoundCore::startPendingEngine()
         m_engine = m_pendingEngine;
         m_pendingEngine = 0;
         m_engine->play();
+        m_handler->setCurrentEngine(m_engine);
+    }
+    else if(state() == Qmmp::Stopped && m_error)
+    {
+        m_error = false;
+        m_handler->dispatch(Qmmp::NormalError);
     }
 }
 
