@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2011 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -44,6 +44,8 @@ ListWidget::ListWidget(QWidget *parent)
     m_update = false;
     m_skin = Skin::instance();
     m_popupWidget = 0;
+    m_metrics = 0;
+    m_extra_metrics = 0;
     loadColors();
     m_menu = new QMenu(this);
     m_scroll_direction = NONE;
@@ -66,21 +68,32 @@ ListWidget::ListWidget(QWidget *parent)
 
 
 ListWidget::~ListWidget()
-{}
+{
+    if(m_metrics)
+        delete m_metrics;
+    if(m_extra_metrics)
+        delete m_extra_metrics;
+}
 
 void ListWidget::readSettings()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     m_font.fromString(settings.value("PlayList/Font", QApplication::font().toString()).toString());
+    m_extra_font = m_font;
+    m_extra_font.setPointSize(m_font.pointSize() - 1);
     m_show_protocol = settings.value ("PlayList/show_protocol", false).toBool();
     m_show_number = settings.value ("PlayList/show_numbers", true).toBool();
+    m_align_numbres = settings.value ("PlayList/align_numbers", false).toBool();
+    m_show_anchor = settings.value("PlayList/show_anchor", false).toBool();
     bool show_popup = settings.value("PlayList/show_popup", false).toBool();
 
     if (m_update)
     {
         delete m_metrics;
+        delete m_extra_metrics;
         m_metrics = new QFontMetrics(m_font);
-        m_rows = (height() - 3) / m_metrics->height ();
+        m_extra_metrics = new QFontMetrics(m_extra_font);
+        m_rows = height() / (m_metrics->lineSpacing() + 2);
         updateList();
         if(m_popupWidget)
         {
@@ -92,6 +105,7 @@ void ListWidget::readSettings()
     {
         m_update = true;
         m_metrics = new QFontMetrics(m_font);
+        m_extra_metrics = new QFontMetrics(m_extra_font);
     }
     if(show_popup)
         m_popupWidget = new PlayListPopup::PopupWidget(this);
@@ -108,19 +122,29 @@ void ListWidget::loadColors()
 void ListWidget::paintEvent(QPaintEvent *)
 {
     QPainter m_painter(this);
-    //m_painter.setPen(Qt::white);
     m_painter.setFont(m_font);
     m_painter.setBrush(QBrush(m_normal_bg));
     m_painter.drawRect(-1,-1,width()+1,height()+1);
+    int font_y = 0;
 
-    for (int i=0; i<m_titles.size(); ++i )
+    for (int i = 0; i < m_titles.size(); ++i )
     {
-        if (m_model->isSelected(i + m_first))
+        if (m_show_anchor && i == m_anchor_row - m_first)
         {
-            m_painter.setBrush(QBrush(m_selected_bg));
-            m_painter.setPen(m_selected_bg);
-            m_painter.drawRect ( 6, 15+(i-1)*m_metrics->height() + 2,
-                                 width() - 10, m_metrics->height());
+            m_painter.setBrush(m_model->isSelected(i + m_first) ? m_selected_bg : m_normal_bg);
+            m_painter.setPen(m_normal);
+            m_painter.drawRect (6, i * (m_metrics->lineSpacing() + 2),
+                                width() - 10, m_metrics->lineSpacing() + 1);
+        }
+        else
+        {
+            if (m_model->isSelected(i + m_first))
+            {
+                m_painter.setBrush(QBrush(m_selected_bg));
+                m_painter.setPen(m_selected_bg);
+                m_painter.drawRect (6, i * (m_metrics->lineSpacing() + 2),
+                                    width() - 10, m_metrics->lineSpacing() + 1);
+            }
         }
 
         if (m_model->currentRow() == i + m_first)
@@ -128,28 +152,43 @@ void ListWidget::paintEvent(QPaintEvent *)
         else
             m_painter.setPen(m_normal);  //243,58
 
-        m_painter.drawText(10,14+i*m_metrics->height(),m_titles.at(i));
+        font_y = (i + 1) * (2 + m_metrics->lineSpacing()) - 2 - m_metrics->descent();
 
-        if (m_model->isQueued(m_model->item(i + m_first)) ||
-                (m_player->isRepeatable() && (m_model->currentRow() == m_first + i)) || m_show_protocol)
+
+
+        if(m_number_width)
         {
-            QString extra_string = getExtraString(m_first + i);
-
-            int old_size = m_font.pointSize();
-            m_font.setPointSize(old_size - 1 );
-            m_painter.setFont(m_font);
-
-            m_painter.drawText(width() - 10 - m_metrics->width(extra_string) - m_metrics->width(m_times.at(i)),
-                               14+i*m_metrics->height (), extra_string);
-            m_font.setPointSize(old_size);
-            m_painter.setFont(m_font);
-            m_painter.setBrush(QBrush(m_normal_bg));
+            QString number = QString("%1").arg(m_first+i+1);
+            m_painter.drawText(10 + m_number_width - m_extra_metrics->width(number),
+                               font_y, number);
+            m_painter.drawText(10 + m_number_width + m_metrics->width("9"), font_y, m_titles.at(i));
         }
+        else
+            m_painter.drawText(10, font_y, m_titles.at(i));
 
-        m_painter.drawText(width() - 7 - m_metrics->width(m_times.at(i)),
-                           14+i*m_metrics->height (), m_times.at(i));
+
+        QString extra_string = getExtraString(m_first + i);
+        if(!extra_string.isEmpty())
+        {
+            m_painter.setFont(m_extra_font);
+
+            if(m_times.at(i).isEmpty())
+                m_painter.drawText(width() - 7 - m_extra_metrics->width(extra_string),
+                                   font_y, extra_string);
+            else
+                m_painter.drawText(width() - 10 - m_extra_metrics->width(extra_string) -
+                                   m_metrics->width(m_times.at(i)), font_y, extra_string);
+            m_painter.setFont(m_font);
+        }
+        m_painter.drawText(width() - 7 - m_metrics->width(m_times.at(i)), font_y, m_times.at(i));
+    }
+    //draw line
+    if(m_number_width)
+    {
+        m_painter.setPen(m_normal);
+        m_painter.drawLine(10 + m_number_width + m_metrics->width("9") / 2, 2,
+                           10 + m_number_width + m_metrics->width("9") / 2, font_y);
     }
-
 }
 
 void ListWidget::mouseDoubleClickEvent (QMouseEvent *e)
@@ -175,47 +214,55 @@ void ListWidget::mousePressEvent(QMouseEvent *e)
 
     if (INVALID_ROW != row && m_model->count() > row)
     {
-        if (!(Qt::ControlModifier & e->modifiers () ||
-                Qt::ShiftModifier & e->modifiers () ||
-                m_model->isSelected(row)))
+        m_pressed_row = row;
+        if(e->button() == Qt::RightButton)
+        {
             m_model->clearSelection();
+            m_model->setSelected(row, true);
+            m_anchor_row = m_pressed_row;
+            QWidget::mousePressEvent(e);
+            return;
+        }
 
         if (m_model->isSelected(row) && (e->modifiers() == Qt::NoModifier))
+        {
             m_select_on_release = true;
+            QWidget::mousePressEvent(e);
+            return;
+        }
 
-        //qWarning("m_prev_clicked_row: %d",m_prev_clicked_row);
-
-        m_pressed_row = row;
         if ((Qt::ShiftModifier & e->modifiers()))
         {
-
+            bool select = true;
             if (m_pressed_row > m_anchor_row)
             {
-                m_model->clearSelection();
                 for (int j = m_anchor_row;j <= m_pressed_row;j++)
                 {
-                    m_model->setSelected(j, true);
+                    m_model->setSelected(j, select);
                 }
             }
             else
             {
-                m_model->clearSelection();
                 for (int j = m_anchor_row;j >= m_pressed_row;j--)
                 {
-                    m_model->setSelected(j, true);
+                    m_model->setSelected(j, select);
                 }
             }
-        }
-        else
-        {
-            if (!m_model->isSelected(row) || (Qt::ControlModifier & e->modifiers()))
-                m_model->setSelected(row, !m_model->isSelected(row));
-        }
-
-        if (m_model->getSelection(m_pressed_row).count() == 1)
             m_anchor_row = m_pressed_row;
-        //qWarning("m_anchor_row: %d",m_anchor_row);
-
+        }
+        else //ShiftModifier released
+        {
+            if ((Qt::ControlModifier & e->modifiers()))
+            {
+                m_model->setSelected(row, !m_model->isSelected(row));
+            }
+            else //ControlModifier released
+            {
+                m_model->clearSelection();
+                m_model->setSelected(row, true);
+            }
+            m_anchor_row = m_pressed_row;
+        }
         update();
     }
     QWidget::mousePressEvent(e);
@@ -223,7 +270,7 @@ void ListWidget::mousePressEvent(QMouseEvent *e)
 
 void ListWidget::resizeEvent(QResizeEvent *e)
 {
-    m_rows = (e->size().height() - 3) / m_metrics->height ();
+    m_rows = e->size().height() / (m_metrics->lineSpacing() + 2);
     m_scroll = true;
     updateList();
     QWidget::resizeEvent(e);
@@ -293,21 +340,32 @@ void ListWidget::updateList()
     m_times  = m_model->getTimes(m_first, m_rows);
     m_scroll = false;
     //add numbers
-    for (int i = 0; i < m_titles.size() && m_show_number; ++i)
+    for (int i = 0; i < m_titles.size() && m_show_number && !m_align_numbres; ++i)
     {
         QString title = m_titles.at(i);
         m_titles.replace(i, title.prepend(QString("%1").arg(m_first+i+1)+". "));
 
     }
+    //song numbers width
+    if(m_show_number && m_align_numbres && m_model->count())
+    {
+        m_number_width = m_metrics->width("9") * QString::number(m_model->count()).size();
+    }
+    else
+        m_number_width = 0;
+
     //elide title
     QString extra_string;
     for (int i=0; i<m_titles.size(); ++i)
     {
         extra_string = getExtraString(m_first + i);
         int extra_string_space = extra_string.isEmpty() ? 0 : m_metrics->width(extra_string);
+        if(m_number_width)
+            extra_string_space += m_number_width + m_metrics->width("9");
         m_titles.replace(i, m_metrics->elidedText (m_titles.at(i), Qt::ElideRight,
                             width() -  m_metrics->width(m_times.at(i)) - 22 - extra_string_space));
     }
+
     update();
 }
 
@@ -388,15 +446,7 @@ void ListWidget::dropEvent(QDropEvent *event)
 
 void ListWidget::processFileInfo(const QFileInfo& info)
 {
-    if (info.isDir())
-    {
-        m_model->addDirectory(info.absoluteFilePath());
-    }
-    else
-    {
-        m_model->addFile(info.absoluteFilePath());
-        m_model->loadPlaylist(info.absoluteFilePath());
-    }
+    m_model->add(info.absoluteFilePath());
 }
 
 const QString ListWidget::getExtraString(int i)
@@ -406,15 +456,20 @@ const QString ListWidget::getExtraString(int i)
     if (m_show_protocol && m_model->item(i)->url().contains("://"))
         extra_string = "[" + m_model->item(i)->url().split("://").at(0) + "]";
 
-    if (m_player->isRepeatable() && (m_model->currentRow() == i))
-        extra_string += " |R|";
-
     if (m_model->isQueued(m_model->item(i)))
     {
         int index = m_model->queuedIndex(m_model->item(i));
-        extra_string += " |"+QString::number(index + 1)+"|";
+        extra_string += "|"+QString::number(index + 1)+"|";
     }
+
+    if(m_model->currentRow() == i && m_player->isRepeatable())
+        extra_string += "|R|";
+    else if(m_model->isStopAfter(m_model->item(i)))
+        extra_string += "|S|";
+
     extra_string = extra_string.trimmed(); //remove white space
+    if(!extra_string.isEmpty())
+        extra_string.prepend(" ");
     return extra_string;
 }
 
@@ -458,6 +513,7 @@ void ListWidget::mouseMoveEvent(QMouseEvent *e)
             m_prev_y = e->y();
             m_scroll = false;
             m_pressed_row = row;
+            m_anchor_row = row;
         }
     }
     else if(m_popupWidget)
@@ -470,11 +526,10 @@ void ListWidget::mouseMoveEvent(QMouseEvent *e)
 
 void ListWidget::mouseReleaseEvent(QMouseEvent *e)
 {
-    if (false != m_select_on_release)
+    if (m_select_on_release)
     {
         m_model->clearSelection();
         m_model->setSelected(m_pressed_row,true);
-        //if(e->modifiers() != Qt::ShiftModifier)
         m_anchor_row = m_pressed_row;
         m_select_on_release = false;
     }
@@ -487,13 +542,10 @@ void ListWidget::mouseReleaseEvent(QMouseEvent *e)
 
 int ListWidget::rowAt(int y) const
 {
-    if (y <= 14 && y >= 2 && m_model->count())
-        return m_first;
-
-    for (int i = 0; i < qMin(m_rows, m_model->count() - m_first) - 1; ++i)
+    for (int i = 0; i < qMin(m_rows, m_model->count() - m_first); ++i)
     {
-        if ((y >= 14 + i * m_metrics->height ()) && (y <= 14 + (i+1) * m_metrics->height()))
-            return m_first + i + 1;
+        if ((y >= i * (m_metrics->lineSpacing() + 2)) && (y <= (i+1) * (m_metrics->lineSpacing() + 2)))
+            return m_first + i;
     }
     return INVALID_ROW;
 }
