@@ -25,13 +25,16 @@
 #include <QSignalMapper>
 #include <QHBoxLayout>
 #include <QCloseEvent>
-
+#include <qmmpui/playlistitem.h>
+#include <qmmpui/playlistmodel.h>
+#include <qmmpui/playlistmanager.h>
+#include <qmmpui/fileloader.h>
+#include <qmmpui/generalhandler.h>
+#include <qmmp/soundcore.h>
 #include "dock.h"
-#include "playlist.h"
 #include "skin.h"
 #include "listwidget.h"
 #include "button.h"
-
 #include "playlisttitlebar.h"
 #include "playlistslider.h"
 #include "pixmapwidget.h"
@@ -40,17 +43,15 @@
 #include "keyboardmanager.h"
 #include "playlistbrowser.h"
 #include "playlistselector.h"
-#include <qmmpui/playlistitem.h>
-#include <qmmpui/playlistmodel.h>
-#include <qmmpui/playlistmanager.h>
-#include <qmmpui/fileloader.h>
-#include <qmmpui/generalhandler.h>
-#include <qmmp/soundcore.h>
+#include "windowsystem.h"
+#include "actionmanager.h"
+#include "playlist.h"
 
 PlayList::PlayList (PlayListManager *manager, QWidget *parent)
         : QWidget (parent)
 {
     setAttribute(Qt::WA_AlwaysShowToolTips,true);
+    setWindowTitle(tr("Playlist"));
     m_pl_manager = manager;
     m_update = false;
     m_resize = false;
@@ -117,6 +118,14 @@ PlayList::PlayList (PlayListManager *manager, QWidget *parent)
     readSettings();
     setCursor(m_skin->getCursor(Skin::CUR_PNORMAL));
     updatePositions();
+#ifdef Q_WS_X11
+    QString wm_name = WindowSystem::netWindowManagerName();
+    if(wm_name.contains("metacity", Qt::CaseInsensitive) ||
+       wm_name.contains("openbox", Qt::CaseInsensitive))
+        setWindowFlags (Qt::Tool | Qt::FramelessWindowHint);
+    else
+#endif
+        setWindowFlags (Qt::Dialog | Qt::FramelessWindowHint);
 }
 
 PlayList::~PlayList()
@@ -166,62 +175,35 @@ void PlayList::createMenus()
     m_selectMenu = new QMenu (this);
     m_sortMenu = new QMenu (this);
     m_playlistMenu = new QMenu (this);
+    m_copySelectedMenu = new QMenu (tr("&Copy Selection To"), m_listWidget->menu());
+    m_copySelectedMenu->setIcon(QIcon::fromTheme("edit-copy"));
+    connect (m_copySelectedMenu, SIGNAL (aboutToShow ()  ), this, SLOT (generateCopySelectedMenu ()));
+    connect (m_copySelectedMenu, SIGNAL (triggered ( QAction *)  ), this, SLOT (copySelectedMenuActionTriggered( QAction *)));
 }
 
 void PlayList::createActions()
 {
     //add menu
-    QAction *addFileAct = new QAction (tr ("&Add File"),this);
-    addFileAct->setShortcut (tr ("F"));
-    m_addMenu->addAction (addFileAct);
-    connect (addFileAct, SIGNAL (triggered()), parent(), SLOT (addFile ()));
-    m_actions << addFileAct;
-
-    QAction *addDirAct = new QAction (tr ("&Add Directory"),this);
-    addDirAct->setShortcut (tr ("D"));
-    m_addMenu->addAction (addDirAct);
-    connect (addDirAct, SIGNAL (triggered()), parent(), SLOT (addDir ()));
-    m_actions << addDirAct;
-
-    QAction *addUrlAct = new QAction (tr ("&Add Url"),this);
-    addUrlAct->setShortcut (tr ("U"));
-    m_addMenu->addAction (addUrlAct);
-    connect (addUrlAct, SIGNAL (triggered()), parent(), SLOT (addUrl ()));
-    m_actions << addUrlAct;
-
-    //remove menu
-    QAction *remSelAct = new QAction (tr ("&Remove Selected"),this);
-    remSelAct->setShortcut (tr ("Del"));
-    m_subMenu->addAction (remSelAct);
-    connect (remSelAct, SIGNAL (triggered()), m_pl_manager, SLOT (removeSelected ()));
-    addAction (remSelAct);
-
-    QAction *remAllAct = new QAction (tr ("&Remove All"),this);
-    //remAllAct->setShortcut(tr("D")); FIXME: add correct shortcat
-    m_subMenu->addAction (remAllAct);
-    connect (remAllAct, SIGNAL (triggered()), m_pl_manager, SLOT (clear ()));
-    m_actions << remAllAct;
-
-    QAction *remUnselAct = new QAction (tr ("&Remove Unselected"),this);
-    m_subMenu->addAction (remUnselAct);
-    connect (remUnselAct, SIGNAL (triggered()), m_pl_manager, SLOT (removeUnselected ()));
-
+    m_addMenu->addAction(SET_ACTION(ActionManager::PL_ADD_FILE, parent(), SLOT(addFile())));
+    m_addMenu->addAction(SET_ACTION(ActionManager::PL_ADD_DIRECTORY, parent(), SLOT(addDir())));
+    m_addMenu->addAction(SET_ACTION(ActionManager::PL_ADD_URL, parent(), SLOT(addUrl())));
+    //sub menu
+    m_subMenu->addAction(SET_ACTION(ActionManager::PL_REMOVE_SELECTED, m_pl_manager, SLOT(removeSelected())));
+    m_subMenu->addAction(SET_ACTION(ActionManager::PL_REMOVE_ALL, m_pl_manager, SLOT(clear())));
+    m_subMenu->addAction(SET_ACTION(ActionManager::PL_REMOVE_UNSELECTED, m_pl_manager,
+                                SLOT(removeUnselected())));
     m_subMenu->addSeparator();
-    m_subMenu->addAction (tr("Remove unavailable files"), m_pl_manager, SLOT(removeInvalidItems()));
-    m_subMenu->addAction (tr("Remove duplicates"), m_pl_manager, SLOT(removeDuplicates()));
-
-    //listwidget menu
-    QAction *detailsAct = new QAction (tr ("&View Track Details"),this);
-    detailsAct->setShortcut (tr ("Alt+I"));
-    m_listWidget->menu()->addAction (detailsAct);
-    connect (detailsAct, SIGNAL (triggered()), m_pl_manager, SLOT (showDetails ()));
-
-    // sort menu
-    m_sortMenu->addAction (detailsAct);
+    m_subMenu->addAction(SET_ACTION(ActionManager::PL_REMOVE_INVALID, m_pl_manager,
+                                SLOT(removeInvalidItems())));
+    m_subMenu->addAction(SET_ACTION(ActionManager::PL_REMOVE_DUPLICATES, m_pl_manager,
+                                SLOT(removeDuplicates())));
+    //sort menu
+    m_sortMenu->addAction(SET_ACTION(ActionManager::PL_SHOW_INFO, m_pl_manager, SLOT (showDetails ())));
+    m_sortMenu->addAction (ActionManager::instance()->action(ActionManager::PL_SHOW_INFO));
     m_sortMenu->addSeparator();
 
-    QMenu* sort_mode_menu = new QMenu (tr ("Sort List"),m_sortMenu);
-
+    QMenu* sort_mode_menu = new QMenu (tr("Sort List"), m_sortMenu);
+    sort_mode_menu->setIcon(QIcon::fromTheme("view-sort-ascending"));
     QSignalMapper* signalMapper = new QSignalMapper (this);
     QAction* titleAct = sort_mode_menu->addAction (tr ("By Title"));
     connect (titleAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
@@ -247,7 +229,7 @@ void PlayList::createActions()
     connect (dateAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (dateAct, PlayListModel::DATE);
 
-    QAction* trackAct = sort_mode_menu->addAction (tr ("By Track Number"));
+    QAction* trackAct = sort_mode_menu->addAction (tr("By Track Number"));
     connect (trackAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (trackAct, PlayListModel::TRACK);
 
@@ -255,7 +237,8 @@ void PlayList::createActions()
 
     m_sortMenu->addMenu (sort_mode_menu);
 
-    sort_mode_menu = new QMenu (tr ("Sort Selection"),m_sortMenu);
+    sort_mode_menu = new QMenu (tr("Sort Selection"), m_sortMenu);
+    sort_mode_menu->setIcon(QIcon::fromTheme("view-sort-ascending"));
     signalMapper = new QSignalMapper (this);
     titleAct = sort_mode_menu->addAction (tr ("By Title"));
     connect (titleAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
@@ -288,84 +271,44 @@ void PlayList::createActions()
     connect (signalMapper, SIGNAL (mapped (int)), m_pl_manager, SLOT (sortSelection (int)));
 
     m_sortMenu->addMenu (sort_mode_menu);
-
     m_sortMenu->addSeparator();
-    m_sortMenu->addAction (tr ("Randomize List"),m_pl_manager,SLOT (randomizeList()));
-    m_sortMenu->addAction (tr ("Reverse List"),m_pl_manager,SLOT (reverseList()));
-
+    m_sortMenu->addAction (QIcon::fromTheme("media-playlist-shuffle"), tr("Randomize List"),
+                           m_pl_manager, SLOT(randomizeList()));
+    m_sortMenu->addAction (QIcon::fromTheme("view-sort-descending"), tr("Reverse List"),
+                           m_pl_manager, SLOT(reverseList()));
+    //playlist context menu
+    m_listWidget->menu()->addAction(ActionManager::instance()->action(ActionManager::PL_SHOW_INFO));
     m_listWidget->menu()->addSeparator();
     m_listWidget->menu()->addActions (m_subMenu->actions().mid(0,3)); //use 3 first actions
     m_listWidget->menu()->addMenu(GeneralHandler::instance()->createMenu(GeneralHandler::PLAYLIST_MENU,
                                   tr("Actions"), this));
-
     m_listWidget->menu()->addSeparator();
-    m_listWidget->menu()->addAction(tr("&Queue"),m_pl_manager, SLOT(addToQueue()), tr("Q"));
-    m_actions << m_listWidget->menu()->actions();
-
+    m_listWidget->menu()->addAction(SET_ACTION(ActionManager::PL_ENQUEUE, m_pl_manager, SLOT(addToQueue())));
     //select menu
-    QAction *invSelAct = new QAction (tr ("Invert Selection"),this);
-    m_selectMenu->addAction (invSelAct);
-    connect (invSelAct, SIGNAL (triggered()), m_pl_manager, SLOT (invertSelection ()));
-
+    m_selectMenu->addAction(SET_ACTION(ActionManager::PL_INVERT_SELECTION, m_pl_manager,
+                                   SLOT(invertSelection ())));
     m_selectMenu->addSeparator();
-
-    QAction *selNoneAct = new QAction (tr ("&Select None"),this);
-    selNoneAct->setShortcut(tr("Shift+A"));
-    m_selectMenu->addAction (selNoneAct);
-    connect (selNoneAct, SIGNAL (triggered()), m_pl_manager, SLOT (clearSelection ()));
-    this->addAction (selNoneAct);
-
-    QAction *selAllAct = new QAction (tr ("&Select All"),this);
-    selAllAct->setShortcut (tr ("Ctrl+A"));
-    m_actions << selAllAct;
-    m_selectMenu->addAction (selAllAct);
-    connect (selAllAct, SIGNAL (triggered()), m_pl_manager, SLOT (selectAll ()));
-
-    //  Playlist Menu
-    QAction *newListAct = new QAction (tr ("&New List"),this);
-    newListAct->setShortcut (tr ("Ctrl+T"));
-    m_actions << newListAct;
-    m_playlistMenu->addAction (newListAct);
-    connect (newListAct, SIGNAL (triggered()), m_pl_manager, SLOT (createPlayList()));
-    QAction *deleteListAct = new QAction (tr ("&Delete List"),this);
-    deleteListAct->setShortcut (tr ("Ctrl+W"));
-    m_actions << deleteListAct;
-    m_playlistMenu->addAction (deleteListAct);
-    connect (deleteListAct, SIGNAL (triggered()), SLOT (deletePlaylist()));
+    m_selectMenu->addAction(SET_ACTION(ActionManager::PL_CLEAR_SELECTION, m_pl_manager,
+                                   SLOT(clearSelection ())));
+    m_selectMenu->addAction(SET_ACTION(ActionManager::PL_SELECT_ALL, m_pl_manager, SLOT(selectAll())));
+    //Playlist Menu
+    m_playlistMenu->addAction(SET_ACTION(ActionManager::PL_NEW, m_pl_manager, SLOT(createPlayList())));
+    m_playlistMenu->addAction(SET_ACTION(ActionManager::PL_CLOSE, this, SLOT(deletePlaylist())));
     m_playlistMenu->addSeparator();
-
-    QAction *loadListAct = new QAction (tr ("&Load List"),this);
-    loadListAct->setShortcut (tr ("O"));
-    m_actions << loadListAct;
-    m_playlistMenu->addAction (loadListAct);
-    connect (loadListAct, SIGNAL (triggered()), this, SIGNAL (loadPlaylist()));
-
-    QAction *saveListAct = new QAction (tr ("&Save List"),this);
-    saveListAct->setShortcut (tr ("Shift+S"));
-    m_actions << saveListAct;
-    m_playlistMenu->addAction (saveListAct);
-    connect (saveListAct, SIGNAL (triggered()), this, SIGNAL (savePlaylist()));
-
+    m_playlistMenu->addAction(SET_ACTION(ActionManager::PL_LOAD, this, SIGNAL(loadPlaylist())));
+    m_playlistMenu->addAction(SET_ACTION(ActionManager::PL_SAVE, this, SIGNAL(savePlaylist())));
     m_playlistMenu->addSeparator();
-    QAction *nextListAct = new QAction (tr ("&Select Next Playlist"),this);
-    nextListAct->setShortcut (tr ("Ctrl+PgDown"));
-    m_actions << nextListAct;
-    m_playlistMenu->addAction (nextListAct);
-    connect (nextListAct, SIGNAL (triggered()), m_pl_manager, SLOT (selectNextPlayList()));
-
-    QAction *previousListAct = new QAction (tr ("&Select Previous Playlist"),this);
-    previousListAct->setShortcut (tr ("Ctrl+PgUp"));
-    m_actions << previousListAct;
-    m_playlistMenu->addAction (previousListAct);
-    connect (previousListAct, SIGNAL (triggered()), m_pl_manager, SLOT (selectPreviousPlayList()));
-
-    QAction *browseListsAct = new QAction (tr ("&Show Playlists"),this);
-    browseListsAct->setShortcut (tr ("P"));
-    m_actions << browseListsAct;
-    m_playlistMenu->addAction (browseListsAct);
-    connect (browseListsAct, SIGNAL (triggered()), SLOT (showPlayLists()));
-
-    Dock::instance()->addActions (m_actions);
+    m_playlistMenu->addAction(SET_ACTION(ActionManager::PL_SELECT_NEXT, m_pl_manager,
+                                     SLOT(selectNextPlayList())));
+    m_playlistMenu->addAction(SET_ACTION(ActionManager::PL_SELECT_PREVIOUS, m_pl_manager,
+                                     SLOT(selectPreviousPlayList())));
+    m_playlistMenu->addAction(SET_ACTION(ActionManager::PL_SHOW_MANAGER, this, SLOT(showPlayLists())));
+    Dock::instance()->addActions (m_addMenu->actions());
+    Dock::instance()->addActions (m_subMenu->actions());
+    Dock::instance()->addActions (m_sortMenu->actions());
+    Dock::instance()->addActions (m_listWidget->menu()->actions());
+    Dock::instance()->addActions (m_selectMenu->actions());
+    Dock::instance()->addActions (m_playlistMenu->actions());
 }
 
 void PlayList::closeEvent (QCloseEvent *e)
@@ -377,27 +320,28 @@ void PlayList::closeEvent (QCloseEvent *e)
 
 void PlayList::paintEvent (QPaintEvent *)
 {
-    int m_sx = (width()-275*m_ratio) /25;
-    int m_sy = (height()-116*m_ratio) /29;
-    drawPixmap (m_sx, m_sy);
-}
+    int sx = (width()-275*m_ratio) /25;
+    int sy = (height()-116*m_ratio) /29;
 
-void PlayList::drawPixmap (int sx, int sy)
-{
-    QPainter paint;
-    paint.begin (this);
-    paint.drawPixmap (0,20*m_ratio, m_skin->getPlPart (Skin::PL_LFILL));
+    QPainter paint(this);
+    drawPixmap (&paint, 0, 20*m_ratio, m_skin->getPlPart (Skin::PL_LFILL));
     for (int i = 1; i<sy+2*m_ratio; i++)
     {
-        paint.drawPixmap (0,20*m_ratio+29*i,m_skin->getPlPart (Skin::PL_LFILL));
+        drawPixmap (&paint, 0, 20*m_ratio+29*i, m_skin->getPlPart (Skin::PL_LFILL));
     }
-    paint.drawPixmap (0,78*m_ratio+29*sy,m_skin->getPlPart (Skin::PL_LSBAR));
+    drawPixmap (&paint, 0, 78*m_ratio+29*sy, m_skin->getPlPart (Skin::PL_LSBAR));
+
     for (int i = 0; i<sx; i++)
     {
-        paint.drawPixmap (125*m_ratio+i*25,78*m_ratio+sy*29,m_skin->getPlPart (Skin::PL_SFILL1));
+        drawPixmap (&paint, 125*m_ratio+i*25,78*m_ratio+sy*29,m_skin->getPlPart (Skin::PL_SFILL1));
     }
-    paint.drawPixmap (125*m_ratio+sx*25,78*m_ratio+sy*29,m_skin->getPlPart (Skin::PL_RSBAR));
-    paint.end();
+    drawPixmap (&paint,125*m_ratio+sx*25,78*m_ratio+sy*29,m_skin->getPlPart (Skin::PL_RSBAR));
+
+}
+
+void PlayList::drawPixmap (QPainter *painter, int x, int y, const QPixmap &pix)
+{
+    style()->drawItemPixmap(painter, QRect(x, y, pix.width(), pix.height()), Qt::AlignCenter, pix);
 }
 
 void PlayList::resizeEvent (QResizeEvent *)
@@ -424,12 +368,12 @@ void PlayList::mouseMoveEvent (QMouseEvent *e)
 #ifdef Q_OS_WIN32
         int sx = (width()-275) /25;
         int sy = (height()-116) /29;
-	if(width() < e->x() - 14)
+    if(width() < e->x() - 14)
            sx++;
-	else if(width() > e->x() + 14)
+    else if(width() > e->x() + 14)
            sx--;
         if(height() < e->y() - 14)
-           sy++;	
+           sy++;
         else if(height() > e->y() + 14)
            sy--;
         resize (275+25*sx,116+29*sy);
@@ -464,11 +408,15 @@ void PlayList::readSettings()
         if(!m_pl_selector)
             m_pl_selector = new PlayListSelector(m_pl_manager, this);
         m_pl_selector->show();
+        m_listWidget->menu()->insertMenu(m_listWidget->menu()->actions().at(2),m_copySelectedMenu);
     }
     else
     {
         if(m_pl_selector)
+        {
             m_pl_selector->deleteLater();
+            m_listWidget->menu()->removeAction(m_copySelectedMenu->menuAction());
+        }
         m_pl_selector = 0;
     }
     if (m_update)
@@ -481,16 +429,23 @@ void PlayList::readSettings()
     }
     else
     {
-        if (settings.value("General/openbox_compat", false).toBool() ||
-            settings.value("General/metacity_compat", false).toBool())
-            setWindowFlags (Qt::Tool | Qt::FramelessWindowHint);
-        else
-            setWindowFlags (Qt::Dialog | Qt::FramelessWindowHint); 
         move (settings.value ("PlayList/pos", QPoint (100, 332)).toPoint());  //position
         m_update = true;
     }
 }
 
+#ifdef Q_WS_X11
+bool PlayList::event (QEvent *event)
+{
+    if(event->type() == QEvent::WinIdChange || event->type() == QEvent::Show)
+    {
+        WindowSystem::ghostWindow(winId());
+        WindowSystem::setWinHint(winId(), "playlist", "Qmmp");
+    }
+    return QWidget::event(event);
+}
+#endif
+
 void PlayList::writeSettings()
 {
     QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
@@ -590,6 +545,54 @@ void PlayList::showPlayLists()
         m_pl_browser->show();
 }
 
+void PlayList::generateCopySelectedMenu()
+{
+    m_copySelectedMenu->clear();
+    QAction* action = m_copySelectedMenu->addAction (tr ("&New PlayList"));
+    action->setIcon(QIcon::fromTheme("document-new"));
+    m_copySelectedMenu->addSeparator();
+
+    foreach(QString name, m_pl_manager->playListNames())
+    {
+        action = m_copySelectedMenu->addAction("&"+name.replace("&", "&&"));
+    }
+}
+
+void PlayList::copySelectedMenuActionTriggered( QAction * action)
+{
+    PlayListModel *targetPlayList = 0;
+    QString actionText=action->text();
+    if(action == m_copySelectedMenu->actions().at(0))//actionText == tr ("&New PlayList"))
+    {
+        targetPlayList = m_pl_manager->createPlayList(m_pl_manager->selectedPlayList()->name());
+    }
+    else
+    {
+        actionText.remove(0,1).replace("&&", "&");
+        foreach(PlayListModel *model, m_pl_manager->playLists())
+        {
+            //if("&" + model->name().replace("&", "&&") == actionText)
+            if(model->name() == actionText)
+            {
+                targetPlayList=model;
+                break;
+            }
+        }
+    }
+    if(!targetPlayList)
+    {
+        qWarning("Error: Cannot find target playlist '%s'",qPrintable(actionText));
+        return;
+    }
+    QList <PlayListItem *> theCopy;
+    foreach(PlayListItem *item, m_pl_manager->selectedPlayList()->getSelectedItems())
+    {
+        PlayListItem *newItem = new PlayListItem(*item);
+        theCopy << newItem;
+    }
+    targetPlayList->add(theCopy);
+}
+
 void PlayList::setMinimalMode(bool b)
 {
     if(!m_shaded)
