@@ -248,6 +248,11 @@ void PlayListTitleBar::shade()
     updatePositions();
 }
 
+void PlayListTitleBar::mouseDoubleClickEvent (QMouseEvent *)
+{
+       PlayListTitleBar::shade();
+}
+
 void PlayListTitleBar::showCurrent()
 {
     if (m_model)
